.. role:: hidden
    :class: hidden-section

Parameter Group
===============

.. currentmodule:: sconce.parameter_group


:hidden:`ParameterGroup`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ParameterGroup
    :members:
